/* -------------------------------------------------------------------
   File "MagSta_a_3Dp.pro"  

    Magnetostatics - Magnetic vector potential a formulation (3D)
   ------------------------------------------------------------------- 
*/


Group {
  DefineGroup[ Boundary];
}

Jacobian {
  { Name Vol ;
    Case { { Region Boundary ;
             Jacobian Sur ; } 
           { Region All ; Jacobian Vol ; }
    }
  }
}

Group {
  DefineGroup[ Domain_Mag, DomainS_Mag ,Boundary];
}

Function {
  DefineFunction[ nu ];
  DefineFunction[ Hc ];
}

FunctionSpace {

                                                    // Magnetic vector potential a (b = curl a)
  { Name Hcurl_a_Mag_3D; Type Form1;
                                                    // a = a  s
    BasisFunction {                                 //      e  e
      { Name se; NameOfCoef ae; Function BF_Edge; 
        Support Domain_Mag; Entity EdgesOf[All]; }}
    Constraint {
      { NameOfCoef ae; EntityType EdgesOf ; NameOfConstraint a;} 
      { NameOfCoef ae; EntityType EdgesOfTreeIn;  EntitySubType StartingOn; NameOfConstraint Gauge; }
    }
  }
  
}

Formulation {
  { Name Magnetostatics_a_3D; Type FemEquation;
    Quantity {
      { Name a ; Type Local; NameOfSpace Hcurl_a_Mag_3D; }}
    Equation {
      Galerkin { [ nu[] * Dof{Curl a} , {Curl a} ]; 	In Domain_Mag;
                 Jacobian Vol; Integration CurlCurl; }
      Galerkin { [ - Hc[{Curl a}] , {Curl a} ]; 		In DomainS_Mag;
                 Jacobian Vol; Integration CurlCurl; }
    }
  }
}

/*      Galerkin { [ nu[{Curl a}] * Dof{Curl a} , {Curl a} ]; 	In Domain_Mag;
                 Jacobian Vol; Integration CurlCurl; } */
/*      Galerkin { [ - Hc[] , {Curl a} ]; 		In DomainS_Mag;
                 Jacobian Vol; Integration CurlCurl; } */











Resolution {
  { Name MagSta_a_3D;
    System {
      { Name Sys_Mag; NameOfFormulation Magnetostatics_a_3D; }}



 
Operation {
InitSolution [Sys_Mag];  
IterativeLoop[NL_NbrMaxIter, NL_Eps, NL_Relax] {GenerateJac[Sys_Mag]; SolveJac[Sys_Mag];}
 SaveSolution[Sys_Mag];
}





/*   Operation {
      Generate[Sys_Mag]; Solve[Sys_Mag]; SaveSolution[Sys_Mag];
    }   */


  }
}

PostProcessing {
  { Name MagSta_a_3D; NameOfFormulation Magnetostatics_a_3D;
    Quantity {
      { Name a; Value { Local { [ {a} ]; In Domain_Mag; Jacobian Vol; } } }
      { Name az; Value { Local { [ CompZ[{a}] ]; In Domain_Mag; Jacobian Vol; } } }
      { Name Hc; Value { Local { [ Hc[{Curl a}] ]; In DomainS_Mag; Jacobian Vol; } } }
      { Name nu; Value { Local { [ nu[] ]; In Domain_Mag; Jacobian Vol; } } }
      { Name b; Value { Local { [ {Curl a} ]; In Domain_Mag; Jacobian Vol; } } }
      { Name h; Value { Local { [ nu[] * {Curl a} ]; In Domain_Mag; Jacobian Vol; } } }
      { Name nb; Value { Local { [ Norm[{Curl a}] ]; In Domain_Mag; Jacobian Vol; } } }
      { Name na; Value { Local { [ Norm[{a}] ]; In Domain_Mag; Jacobian Vol; } } }
    }
  }
}
