/* File "ring_magnet.pro"  */
// for 3D example b-conforming

Group {

   Air    = Region[ {1, 100009} ];
   Mag   = Region[ {2, 3} ];
   Namag  = Region [ {4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19} ];
   Rope = Region [ {100001, 100002, 100003, 100004, 100005, 100006} ];
   
  
  Outer_Boundary  = Region[ {101} ]; //  ࠭    
  Mag_Boundary  =  Region[ {102, 103} ]; // ࠭ ﭭ 
 
  Metall_Boundary = Region[ {104, 105, 106, 107, 108, 109, 110, 111, 112, 113, 114, 115, 116, 117, 118, 119} ]; // ࠭ ⠫ 
 

  Domain_Mag =      Region[ {Air,Mag, Namag, Rope} ];
  DomainS_Mag  =    Region[ {Mag} ]; 
  Boundary     =    Region[ {Outer_Boundary ,Mag_Boundary, Metall_Boundary}];
}


NL_NbrMaxIter = 30;
NL_Eps = 1.e-4;
NL_Relax = 1;





Function {

  mu0 = 4.e-7 * Pi;
  murMag = 1.2;
  muMetall = 1000.;

  nu [ Region[{Air}] ]  = 1. / mu0;
  nu [ Region[{Mag}] ]  = 1. / (murMag * mu0);
 
//  nu [ Region[{Namag}] ]  = 1. / (muMetall * mu0);
//  nu [ Region[{Rope}] ]  = 1. / (muMetall * mu0);


data_b = {0.0000, 0.2000, 0.5200, 1.0000, 1.4200, 1.6000, 1.8036, 2.1378, 2.2600, 2.2800, 2.2850, 2.2855, 2.2860};
data_nu = {795.78, 795.78, 459.10, 557.04, 1120.80, 1989.40, 3924.30, 13601.00, 26549.00, 43860.00, 131290.00, 262520.00, 4.3754e+08};

data_bpm = {-1.13,0.0, 0.565, 1.13};
data_hpm = {1640000.0,820000.0,410000.0,0.0};


/* This is for vector magnetic potential formulation with a Picard scheme */
  nu_steel_couples = {   /* B (Tesla), H (A/m) / B (Tesla) */
       0.0000,    795.78,
 /*      0.2000,    795.78, 
       0.5200,    459.10,
       1.0000,    557.04,
       1.4200,   1120.80,
       1.6000,   1989.40,
       1.8036,   3924.30,
       2.1378,  13601.00,
       2.2600,  26549.00,
       2.2800,  43860.00,
       2.2850, 131290.00,
       2.2855, 262520.00,            */
       2.2860, 4.3754e+08     // extra
  };




/* mu [ Domain_C ] = InterpolationLinear[Norm[$1]]{ListAlt[data_h, data_mu]}; */

/*  nu [ Region[{Namag}] ]  = InterpolationLinear[Norm[$1]]{ListAlt[data_b, data_nu]}; 
  nu [ Region[{Rope}] ]  = InterpolationLinear[Norm[$1]]{ListAlt[data_b, data_nu]};
*/



Hc [ Mag] = Vector [ InterpolationLinear[CompX[$1]]{ListAlt[data_bpm, data_hpm]},0.0,0.0];

nu[Region[{Namag}]] = InterpolationLinear[Norm[$1]]{List[nu_steel_couples]};
nu[Region[{Rope}]] = InterpolationLinear[Norm[$1]]{List[nu_steel_couples]};



}




Constraint {

  { Name Gauge; Type Assign;
    Case {{ Region Domain_Mag; SubRegion Boundary  ; Value 0.; }} 
  } 
  { Name a; Type Assign;
    Case {{ Region  Outer_Boundary  ; Value 0.; }}
  }
}

Include "Integration_Lib.pro"
Include "MagSta_a_3Dp.pro"

PostOperation {

  { Name Map_a; NameOfPostProcessing MagSta_a_3D;
    Operation {

 //     Print[ a,  OnElementsOf Domain_Mag,  File "ring_magnet_a.pos" ];
 //     Print[ az, OnElementsOf Domain_Mag,  File "ring_magnet_az.pos" ];
      Print[ Hc, OnElementsOf DomainS_Mag, File "ring_magnet_Hc.pos" ];
 //     Print[ nu, OnElementsOf Domain_Mag,  File "ring_magnet_nu.pos" ];
      Print[ b,  OnElementsOf Domain_Mag,  File "ring_magnet_b.pos" ];
      Print[ h,  OnElementsOf Domain_Mag,  File "ring_magnet_h.pos" ];
 //     Print[ nb, OnElementsOf Domain_Mag,  File "ring_magnet_nb.pos" ];
 //     Print[ na, OnElementsOf Domain_Mag,  File "ring_magnet_na.pos" ];


/*
     { Name a; Value { Local { [ {a} ]; In Domain_Mag; Jacobian Vol; } } }
      { Name az; Value { Local { [ CompZ[{a}] ]; In Domain_Mag; Jacobian Vol; } } }
      { Name Hc; Value { Local { [ Hc[] ]; In DomainS_Mag; Jacobian Vol; } } }
      { Name nu; Value { Local { [ nu[] ]; In Domain_Mag; Jacobian Vol; } } }
      { Name b; Value { Local { [ {Curl a} ]; In Domain_Mag; Jacobian Vol; } } }
      { Name h; Value { Local { [ nu[] * {Curl a} ]; In Domain_Mag; Jacobian Vol; } } }
      { Name nb; Value { Local { [ Norm[{Curl a}] ]; In Domain_Mag; Jacobian Vol; } } }
      { Name na; Value { Local { [ Norm[{a}] ]; In Domain_Mag; Jacobian Vol; } } }
*/
    }
  }

}
